@@ -8,5 +8,5 @@
 # Licensed under the MIT license.
 ##
 
-from info.version import __version__ # define __version__ variable
-from info.desc import __desc__ # define __desc__ variable for description
+from info import __version__ # define __version__ variable
+from info import __desc__ # define __desc__ variable for description
