@@ -3,10 +3,12 @@
 ##
 # PyChat
 # https://github.com/leosartaj/PyChat.git
+#
 # Copyright (c) 2014 Sartaj Singh
 # Licensed under the MIT license.
 ##
 
+
 """
 Upper key and lower key functionality
 when pressed gives last written text
@@ -35,6 +37,7 @@ class stack:
         textList = self.textList
         textList.append(text)
         self.reset_point()
+        return textList # only for testing purposes
 
     def pop(self):
         """
