@@ -8,6 +8,8 @@
 # Licensed under the MIT license.
 ##
 
+from twisted.python import log
+from twisted.internet import reactor
 from twisted.internet.protocol import ServerFactory
 
 class serverFactory(ServerFactory):
@@ -42,6 +44,19 @@ class serverFactory(ServerFactory):
         """
         return self.users
 
+    def getPeername(self, ip):
+        for user in self.getUsers:
+            if user[1] == ip:
+                return user[0]
+        return None
+
+    def disconnect(self):
+        """
+        Disconnects from all the clients
+        """
+        for client in self.clients:
+            client.transport.loseConnection()
+
     def removeUsers(self, name, ip):
         """
         returns list of tuples of name and ip of connected clients
